@@ -58,9 +58,144 @@ if TYPE_CHECKING:
     from web3.contract import Contract  # noqa: F401
 
 
+class AsyncEthModuleTest:
+    @pytest.mark.asyncio
+    async def test_eth_gas_price(self, async_w3: "Web3") -> None:
+        gas_price = await async_w3.eth.gas_price  # type: ignore
+        assert gas_price > 0
+
+    @pytest.mark.asyncio
+    async def test_isConnected(self, async_w3: "Web3") -> None:
+        is_connected = await async_w3.isConnected()  # type: ignore
+        assert is_connected is True
+
+    @pytest.mark.asyncio
+    async def test_eth_send_transaction(
+        self, async_w3: "Web3", unlocked_account_dual_type: ChecksumAddress
+    ) -> None:
+        txn_params: TxParams = {
+            'from': unlocked_account_dual_type,
+            'to': unlocked_account_dual_type,
+            'value': Wei(1),
+            'gas': Wei(21000),
+            'gasPrice': await async_w3.eth.gas_price,  # type: ignore
+        }
+        txn_hash = await async_w3.eth.send_transaction(txn_params)  # type: ignore
+        txn = await async_w3.eth.get_transaction(txn_hash)  # type: ignore
+
+        assert is_same_address(txn['from'], cast(ChecksumAddress, txn_params['from']))
+        assert is_same_address(txn['to'], cast(ChecksumAddress, txn_params['to']))
+        assert txn['value'] == 1
+        assert txn['gas'] == 21000
+        assert txn['gasPrice'] == txn_params['gasPrice']
+
+    @pytest.mark.asyncio
+    async def test_gas_price_strategy_middleware(
+        self, async_w3: "Web3", unlocked_account_dual_type: ChecksumAddress
+    ) -> None:
+        txn_params: TxParams = {
+            'from': unlocked_account_dual_type,
+            'to': unlocked_account_dual_type,
+            'value': Wei(1),
+            'gas': Wei(21000),
+        }
+
+        def higher_gas_price_strategy(web3: "Web3", txn: TxParams) -> Wei:
+            return Wei(20)
+
+        async_w3.eth.set_gas_price_strategy(higher_gas_price_strategy)
+
+        txn_hash = await async_w3.eth.send_transaction(txn_params)  # type: ignore
+        txn = await async_w3.eth.get_transaction(txn_hash)  # type: ignore
+
+        assert txn['gasPrice'] == 20
+
+    @pytest.mark.asyncio
+    async def test_eth_estimate_gas(
+        self, async_w3: "Web3", unlocked_account_dual_type: ChecksumAddress
+    ) -> None:
+        gas_estimate = await async_w3.eth.estimate_gas({  # type: ignore
+            'from': unlocked_account_dual_type,
+            'to': unlocked_account_dual_type,
+            'value': Wei(1),
+        })
+        assert is_integer(gas_estimate)
+        assert gas_estimate > 0
+
+    @pytest.mark.asyncio
+    async def test_eth_getBlockByHash(
+        self, async_w3: "Web3", empty_block: BlockData
+    ) -> None:
+        block = await async_w3.eth.get_block(empty_block['hash'])  # type: ignore
+        assert block['hash'] == empty_block['hash']
+
+    @pytest.mark.asyncio
+    async def test_eth_getBlockByHash_not_found(
+        self, async_w3: "Web3", empty_block: BlockData
+    ) -> None:
+        with pytest.raises(BlockNotFound):
+            await async_w3.eth.get_block(UNKNOWN_HASH)  # type: ignore
+
+    @pytest.mark.asyncio
+    async def test_eth_getBlockByHash_pending(
+        self, async_w3: "Web3"
+    ) -> None:
+        block = await async_w3.eth.get_block('pending')  # type: ignore
+        assert block['hash'] is None
+
+    @pytest.mark.asyncio
+    async def test_eth_getBlockByNumber_with_integer(
+        self, async_w3: "Web3", empty_block: BlockData
+    ) -> None:
+        block = await async_w3.eth.get_block(empty_block['number'])  # type: ignore
+        assert block['number'] == empty_block['number']
+
+    @pytest.mark.asyncio
+    async def test_eth_getBlockByNumber_latest(
+        self, async_w3: "Web3", empty_block: BlockData
+    ) -> None:
+        current_block_number = await async_w3.eth.block_number  # type: ignore
+        block = await async_w3.eth.get_block('latest')  # type: ignore
+        assert block['number'] == current_block_number
+
+    @pytest.mark.asyncio
+    async def test_eth_getBlockByNumber_not_found(
+        self, async_w3: "Web3", empty_block: BlockData
+    ) -> None:
+        with pytest.raises(BlockNotFound):
+            await async_w3.eth.get_block(BlockNumber(12345))  # type: ignore
+
+    @pytest.mark.asyncio
+    async def test_eth_getBlockByNumber_pending(
+        self, async_w3: "Web3", empty_block: BlockData
+    ) -> None:
+        current_block_number = await async_w3.eth.block_number  # type: ignore
+        block = await async_w3.eth.get_block('pending')  # type: ignore
+        assert block['number'] == current_block_number + 1
+
+    @pytest.mark.asyncio
+    async def test_eth_getBlockByNumber_earliest(
+        self, async_w3: "Web3", empty_block: BlockData
+    ) -> None:
+        genesis_block = await async_w3.eth.get_block(BlockNumber(0))  # type: ignore
+        block = await async_w3.eth.get_block('earliest')  # type: ignore
+        assert block['number'] == 0
+        assert block['hash'] == genesis_block['hash']
+
+    @pytest.mark.asyncio
+    async def test_eth_getBlockByNumber_full_transactions(
+        self, async_w3: "Web3", block_with_txn: BlockData
+    ) -> None:
+        block = await async_w3.eth.get_block(block_with_txn['number'], True)  # type: ignore
+        transaction = block['transactions'][0]
+        assert transaction['hash'] == block_with_txn['transactions'][0]
+
+
 class EthModuleTest:
     def test_eth_protocol_version(self, web3: "Web3") -> None:
-        protocol_version = web3.eth.protocol_version
+        with pytest.warns(DeprecationWarning,
+                          match="This method has been deprecated in some clients"):
+            protocol_version = web3.eth.protocol_version
 
         assert is_string(protocol_version)
         assert protocol_version.isdigit()
@@ -140,6 +275,11 @@ class EthModuleTest:
         assert is_integer(block_number)
         assert block_number >= 0
 
+    def test_eth_get_block_number(self, web3: "Web3") -> None:
+        block_number = web3.eth.get_block_number()
+        assert is_integer(block_number)
+        assert block_number >= 0
+
     def test_eth_blockNumber(self, web3: "Web3") -> None:
         with pytest.warns(DeprecationWarning):
             block_number = web3.eth.blockNumber
@@ -161,10 +301,8 @@ class EthModuleTest:
     def test_eth_getBalance_deprecated(self, web3: "Web3") -> None:
         coinbase = web3.eth.coinbase
 
-        with pytest.warns(DeprecationWarning):
-            with pytest.raises(InvalidAddress):
-                web3.eth.getBalance(ChecksumAddress(HexAddress(HexStr(coinbase.lower()))))
-
+        with pytest.warns(DeprecationWarning,
+                          match='getBalance is deprecated in favor of get_balance'):
             balance = web3.eth.getBalance(coinbase)
 
         assert is_integer(balance)
@@ -412,7 +550,59 @@ class EthModuleTest:
             assert is_bytes(signature)
             assert len(signature) == 32 + 32 + 1
 
-    def test_eth_signTypedData(
+    def test_eth_sign_typed_data(
+        self,
+        web3: "Web3",
+        unlocked_account_dual_type: ChecksumAddress,
+        skip_if_testrpc: Callable[["Web3"], None],
+    ) -> None:
+        validJSONMessage = '''
+            {
+                "types": {
+                    "EIP712Domain": [
+                        {"name": "name", "type": "string"},
+                        {"name": "version", "type": "string"},
+                        {"name": "chainId", "type": "uint256"},
+                        {"name": "verifyingContract", "type": "address"}
+                    ],
+                    "Person": [
+                        {"name": "name", "type": "string"},
+                        {"name": "wallet", "type": "address"}
+                    ],
+                    "Mail": [
+                        {"name": "from", "type": "Person"},
+                        {"name": "to", "type": "Person"},
+                        {"name": "contents", "type": "string"}
+                    ]
+                },
+                "primaryType": "Mail",
+                "domain": {
+                    "name": "Ether Mail",
+                    "version": "1",
+                    "chainId": "0x01",
+                    "verifyingContract": "0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC"
+                },
+                "message": {
+                    "from": {
+                        "name": "Cow",
+                        "wallet": "0xCD2a3d9F938E13CD947Ec05AbC7FE734Df8DD826"
+                    },
+                    "to": {
+                        "name": "Bob",
+                        "wallet": "0xbBbBBBBbbBBBbbbBbbBbbbbBBbBbbbbBbBbbBBbB"
+                    },
+                    "contents": "Hello, Bob!"
+                }
+            }
+        '''
+        skip_if_testrpc(web3)
+        signature = HexBytes(web3.eth.sign_typed_data(
+            unlocked_account_dual_type,
+            json.loads(validJSONMessage)
+        ))
+        assert len(signature) == 32 + 32 + 1
+
+    def test_eth_signTypedData_deprecated(
         self,
         web3: "Web3",
         unlocked_account_dual_type: ChecksumAddress,
@@ -464,7 +654,7 @@ class EthModuleTest:
         ))
         assert len(signature) == 32 + 32 + 1
 
-    def test_invalid_eth_signTypedData(
+    def test_invalid_eth_sign_typed_data(
         self,
         web3: "Web3",
         unlocked_account_dual_type: ChecksumAddress,
@@ -512,7 +702,7 @@ class EthModuleTest:
         '''
         with pytest.raises(ValueError,
                            match=r".*Expected 2 items for array type Person\[2\], got 1 items.*"):
-            web3.eth.signTypedData(
+            web3.eth.sign_typed_data(
                 unlocked_account_dual_type,
                 json.loads(invalid_typed_message)
             )
@@ -735,7 +925,7 @@ class EthModuleTest:
             'gasPrice': web3.eth.gas_price,
         }
         txn_hash = web3.eth.send_transaction(txn_params)
-        web3.eth.waitForTransactionReceipt(txn_hash)
+        web3.eth.wait_for_transaction_receipt(txn_hash)
 
         txn_params['gasPrice'] = Wei(web3.eth.gas_price * 2)
         with pytest.raises(ValueError, match="Supplied transaction with hash"):
@@ -808,7 +998,7 @@ class EthModuleTest:
         def higher_gas_price_strategy(web3: "Web3", txn: TxParams) -> Wei:
             return Wei(20)
 
-        web3.eth.setGasPriceStrategy(higher_gas_price_strategy)
+        web3.eth.set_gas_price_strategy(higher_gas_price_strategy)
 
         txn_params.pop('gasPrice')
         replace_txn_hash = web3.eth.replace_transaction(txn_hash, txn_params)
@@ -830,7 +1020,7 @@ class EthModuleTest:
         def lower_gas_price_strategy(web3: "Web3", txn: TxParams) -> Wei:
             return Wei(5)
 
-        web3.eth.setGasPriceStrategy(lower_gas_price_strategy)
+        web3.eth.set_gas_price_strategy(lower_gas_price_strategy)
 
         txn_params.pop('gasPrice')
         replace_txn_hash = web3.eth.replace_transaction(txn_hash, txn_params)
@@ -838,7 +1028,7 @@ class EthModuleTest:
         # Strategy provides lower gas price - minimum preferred
         assert replace_txn['gasPrice'] == 12
 
-    def test_eth_modifyTransaction(
+    def test_eth_modify_transaction(
         self, web3: "Web3", unlocked_account: ChecksumAddress
     ) -> None:
         txn_params: TxParams = {
@@ -850,7 +1040,7 @@ class EthModuleTest:
         }
         txn_hash = web3.eth.send_transaction(txn_params)
 
-        modified_txn_hash = web3.eth.modifyTransaction(
+        modified_txn_hash = web3.eth.modify_transaction(
             txn_hash, gasPrice=(cast(int, txn_params['gasPrice']) * 2), value=2
         )
         modified_txn = web3.eth.get_transaction(modified_txn_hash)
@@ -861,20 +1051,40 @@ class EthModuleTest:
         assert modified_txn['gas'] == 21000
         assert modified_txn['gasPrice'] == cast(int, txn_params['gasPrice']) * 2
 
+    def test_eth_modifyTransaction_deprecated(
+        self, web3: "Web3", unlocked_account: ChecksumAddress
+    ) -> None:
+        txn_params: TxParams = {
+            'from': unlocked_account,
+            'to': unlocked_account,
+            'value': Wei(1),
+            'gas': Wei(21000),
+            'gasPrice': web3.eth.gas_price,
+        }
+        txn_hash = web3.eth.send_transaction(txn_params)
+        with pytest.warns(
+                DeprecationWarning,
+                match="modifyTransaction is deprecated in favor of modify_transaction"):
+            modified_txn_hash = web3.eth.modifyTransaction(
+                txn_hash, gasPrice=(cast(int, txn_params['gasPrice']) * 2), value=2
+            )
+        modified_txn = web3.eth.get_transaction(modified_txn_hash)
+        assert is_same_address(modified_txn['from'], cast(ChecksumAddress, txn_params['from']))
+        assert is_same_address(modified_txn['to'], cast(ChecksumAddress, txn_params['to']))
+        assert modified_txn['value'] == 2
+        assert modified_txn['gas'] == 21000
+        assert modified_txn['gasPrice'] == cast(int, txn_params['gasPrice']) * 2
+
     @pytest.mark.parametrize(
         'raw_transaction, expected_hash',
         [
-            (
-                # address 0x39EEed73fb1D3855E90Cbd42f348b3D7b340aAA6
-                '0xf8648085174876e8008252089439eeed73fb1d3855e90cbd42f348b3d7b340aaa601801ba0ec1295f00936acd0c2cb90ab2cdaacb8bf5e11b3d9957833595aca9ceedb7aada05dfc8937baec0e26029057abd3a1ef8c505dca2cdc07ffacb046d090d2bea06a',  # noqa: E501
-                '0x1f80f8ab5f12a45be218f76404bda64d37270a6f4f86ededd0eb599f80548c13',
-            ),
             (
                 # private key 0x3c2ab4e8f17a7dea191b8c991522660126d681039509dc3bb31af7c9bdb63518
                 # This is an unfunded account, but the transaction has a 0 gas price, so is valid.
                 # It never needs to be mined, we just want the transaction hash back to confirm.
-                HexBytes('0xf85f808082c35094d898d5e829717c72e7438bad593076686d7d164a80801ba005c2e99ecee98a12fbf28ab9577423f42e9e88f2291b3acc8228de743884c874a077d6bc77a47ad41ec85c96aac2ad27f05a039c4787fca8a1e5ee2d8c7ec1bb6a'),  # noqa: E501
-                '0x98eeadb99454427f6aad7b558bac13e9d225512a6f5e5c11cf48e8d4067e51b5',
+                # tx = {'to': '0x0000000000000000000000000000000000000000', 'value': 0, 'nonce': 0, 'gas': 21000, 'gasPrice': 0, 'chainId': 131277322940537}  # noqa: E501
+                HexBytes('0xf8658080825208940000000000000000000000000000000000000000808086eecac466e115a038176e5f9f1c25ce470ce77856bacbc02dd728ad647bb8b18434ac62c3e8e14fa03279bb3ee1e5202580668ec62b66a7d01355de3d5c4ef18fcfcb88fac56d5f90'),  # noqa: E501
+                '0x6ab943e675003de610b4e94f2e289dc711688df6e150da2bc57bd03811ad0f63',
             ),
         ]
     )
@@ -902,6 +1112,28 @@ class EthModuleTest:
         result = web3.codec.decode_single('uint256', call_result)
         assert result == 18
 
+    def test_eth_call_with_override(
+        self, web3: "Web3", revert_contract: "Contract"
+    ) -> None:
+        coinbase = web3.eth.coinbase
+        txn_params = revert_contract._prepare_transaction(
+            fn_name='normalFunction',
+            transaction={'from': coinbase, 'to': revert_contract.address},
+        )
+        call_result = web3.eth.call(txn_params)
+        result = web3.codec.decode_single('bool', call_result)
+        assert result is True
+
+        # override runtime bytecode: `normalFunction` returns `false`
+        override_code = '0x6080604052348015600f57600080fd5b5060043610603c5760003560e01c8063185c38a4146041578063c06a97cb146049578063d67e4b84146051575b600080fd5b60476071565b005b604f60df565b005b605760e4565b604051808215151515815260200191505060405180910390f35b6040517f08c379a000000000000000000000000000000000000000000000000000000000815260040180806020018281038252601b8152602001807f46756e6374696f6e20686173206265656e2072657665727465642e000000000081525060200191505060405180910390fd5b600080fd5b60008090509056fea2646970667358221220bb71e9e9a2e271cd0fbe833524a3ea67df95f25ea13aef5b0a761fa52b538f1064736f6c63430006010033'  # noqa: E501
+        call_result = web3.eth.call(
+            txn_params,
+            'latest',
+            {revert_contract.address: {'code': override_code}}
+        )
+        result = web3.codec.decode_single('bool', call_result)
+        assert result is False
+
     def test_eth_call_with_0_result(
         self, web3: "Web3", math_contract: "Contract"
     ) -> None:
@@ -949,7 +1181,7 @@ class EthModuleTest:
             )
             web3.eth.call(txn_params)
 
-    def test_eth_estimateGas_revert_with_msg(
+    def test_eth_estimate_gas_revert_with_msg(
         self,
         web3: "Web3",
         revert_contract: "Contract",
@@ -964,9 +1196,9 @@ class EthModuleTest:
                     "to": revert_contract.address,
                 },
             )
-            web3.eth.estimateGas(txn_params)
+            web3.eth.estimate_gas(txn_params)
 
-    def test_eth_estimateGas_revert_without_msg(
+    def test_eth_estimate_gas_revert_without_msg(
         self,
         web3: "Web3",
         revert_contract: "Contract",
@@ -980,12 +1212,12 @@ class EthModuleTest:
                     "to": revert_contract.address,
                 },
             )
-            web3.eth.estimateGas(txn_params)
+            web3.eth.estimate_gas(txn_params)
 
-    def test_eth_estimateGas(
+    def test_eth_estimate_gas(
         self, web3: "Web3", unlocked_account_dual_type: ChecksumAddress
     ) -> None:
-        gas_estimate = web3.eth.estimateGas({
+        gas_estimate = web3.eth.estimate_gas({
             'from': unlocked_account_dual_type,
             'to': unlocked_account_dual_type,
             'value': Wei(1),
@@ -993,10 +1225,23 @@ class EthModuleTest:
         assert is_integer(gas_estimate)
         assert gas_estimate > 0
 
-    def test_eth_estimateGas_with_block(
+    def test_eth_estimateGas_deprecated(
         self, web3: "Web3", unlocked_account_dual_type: ChecksumAddress
     ) -> None:
-        gas_estimate = web3.eth.estimateGas({
+        with pytest.warns(DeprecationWarning,
+                          match="estimateGas is deprecated in favor of estimate_gas"):
+            gas_estimate = web3.eth.estimateGas({
+                'from': unlocked_account_dual_type,
+                'to': unlocked_account_dual_type,
+                'value': Wei(1),
+            })
+        assert is_integer(gas_estimate)
+        assert gas_estimate > 0
+
+    def test_eth_estimate_gas_with_block(
+        self, web3: "Web3", unlocked_account_dual_type: ChecksumAddress
+    ) -> None:
+        gas_estimate = web3.eth.estimate_gas({
             'from': unlocked_account_dual_type,
             'to': unlocked_account_dual_type,
             'value': Wei(1),
@@ -1136,10 +1381,10 @@ class EthModuleTest:
         assert is_dict(transaction)
         assert transaction['hash'] == HexBytes(mined_txn_hash)
 
-    def test_eth_getTransactionReceipt_mined(
+    def test_eth_get_transaction_receipt_mined(
         self, web3: "Web3", block_with_txn: BlockData, mined_txn_hash: HexStr
     ) -> None:
-        receipt = web3.eth.getTransactionReceipt(mined_txn_hash)
+        receipt = web3.eth.get_transaction_receipt(mined_txn_hash)
         assert is_dict(receipt)
         assert receipt['blockNumber'] == block_with_txn['number']
         assert receipt['blockHash'] == block_with_txn['hash']
@@ -1149,7 +1394,23 @@ class EthModuleTest:
         assert receipt['from'] is not None
         assert is_checksum_address(receipt['from'])
 
-    def test_eth_getTransactionReceipt_unmined(
+    def test_eth_getTransactionReceipt_mined_deprecated(
+        self, web3: "Web3", block_with_txn: BlockData, mined_txn_hash: HexStr
+    ) -> None:
+        with pytest.warns(
+                DeprecationWarning,
+                match="getTransactionReceipt is deprecated in favor of get_transaction_receipt"):
+            receipt = web3.eth.getTransactionReceipt(mined_txn_hash)
+        assert is_dict(receipt)
+        assert receipt['blockNumber'] == block_with_txn['number']
+        assert receipt['blockHash'] == block_with_txn['hash']
+        assert receipt['transactionIndex'] == 0
+        assert receipt['transactionHash'] == HexBytes(mined_txn_hash)
+        assert is_checksum_address(receipt['to'])
+        assert receipt['from'] is not None
+        assert is_checksum_address(receipt['from'])
+
+    def test_eth_get_transaction_receipt_unmined(
         self, web3: "Web3", unlocked_account_dual_type: ChecksumAddress
     ) -> None:
         txn_hash = web3.eth.send_transaction({
@@ -1160,16 +1421,16 @@ class EthModuleTest:
             'gasPrice': web3.eth.gas_price,
         })
         with pytest.raises(TransactionNotFound):
-            web3.eth.getTransactionReceipt(txn_hash)
+            web3.eth.get_transaction_receipt(txn_hash)
 
-    def test_eth_getTransactionReceipt_with_log_entry(
+    def test_eth_get_transaction_receipt_with_log_entry(
         self,
         web3: "Web3",
         block_with_txn_with_log: BlockData,
         emitter_contract: "Contract",
         txn_hash_with_log: HexStr,
     ) -> None:
-        receipt = web3.eth.getTransactionReceipt(txn_hash_with_log)
+        receipt = web3.eth.get_transaction_receipt(txn_hash_with_log)
         assert is_dict(receipt)
         assert receipt['blockNumber'] == block_with_txn_with_log['number']
         assert receipt['blockHash'] == block_with_txn_with_log['hash']
@@ -1197,50 +1458,66 @@ class EthModuleTest:
     def test_eth_newFilter(self, web3: "Web3") -> None:
         filter = web3.eth.filter({})
 
-        changes = web3.eth.getFilterChanges(filter.filter_id)
+        changes = web3.eth.get_filter_changes(filter.filter_id)
         assert is_list_like(changes)
         assert not changes
 
-        logs = web3.eth.getFilterLogs(filter.filter_id)
+        logs = web3.eth.get_filter_logs(filter.filter_id)
         assert is_list_like(logs)
         assert not logs
 
-        result = web3.eth.uninstallFilter(filter.filter_id)
+        result = web3.eth.uninstall_filter(filter.filter_id)
+        assert result is True
+
+    def test_eth_newFilter_deprecated(self, web3: "Web3") -> None:
+        filter = web3.eth.filter({})
+
+        changes = web3.eth.get_filter_changes(filter.filter_id)
+        assert is_list_like(changes)
+        assert not changes
+
+        with pytest.warns(DeprecationWarning,
+                          match="getFilterLogs is deprecated in favor of get_filter_logs"):
+            logs = web3.eth.getFilterLogs(filter.filter_id)
+        assert is_list_like(logs)
+        assert not logs
+
+        result = web3.eth.uninstall_filter(filter.filter_id)
         assert result is True
 
     def test_eth_newBlockFilter(self, web3: "Web3") -> None:
         filter = web3.eth.filter('latest')
         assert is_string(filter.filter_id)
 
-        changes = web3.eth.getFilterChanges(filter.filter_id)
+        changes = web3.eth.get_filter_changes(filter.filter_id)
         assert is_list_like(changes)
         assert not changes
 
         # TODO: figure out why this fails in go-ethereum
-        # logs = web3.eth.getFilterLogs(filter.filter_id)
+        # logs = web3.eth.get_filter_logs(filter.filter_id)
         # assert is_list_like(logs)
         # assert not logs
 
-        result = web3.eth.uninstallFilter(filter.filter_id)
+        result = web3.eth.uninstall_filter(filter.filter_id)
         assert result is True
 
     def test_eth_newPendingTransactionFilter(self, web3: "Web3") -> None:
         filter = web3.eth.filter('pending')
         assert is_string(filter.filter_id)
 
-        changes = web3.eth.getFilterChanges(filter.filter_id)
+        changes = web3.eth.get_filter_changes(filter.filter_id)
         assert is_list_like(changes)
         assert not changes
 
         # TODO: figure out why this fails in go-ethereum
-        # logs = web3.eth.getFilterLogs(filter.filter_id)
+        # logs = web3.eth.get_filter_logs(filter.filter_id)
         # assert is_list_like(logs)
         # assert not logs
 
-        result = web3.eth.uninstallFilter(filter.filter_id)
+        result = web3.eth.uninstall_filter(filter.filter_id)
         assert result is True
 
-    def test_eth_getLogs_without_logs(
+    def test_eth_get_logs_without_logs(
         self, web3: "Web3", block_with_txn_with_log: BlockData
     ) -> None:
         # Test with block range
@@ -1249,7 +1526,7 @@ class EthModuleTest:
             "fromBlock": BlockNumber(0),
             "toBlock": BlockNumber(block_with_txn_with_log['number'] - 1),
         }
-        result = web3.eth.getLogs(filter_params)
+        result = web3.eth.get_logs(filter_params)
         assert len(result) == 0
 
         # the range is wrong
@@ -1257,7 +1534,7 @@ class EthModuleTest:
             "fromBlock": block_with_txn_with_log['number'],
             "toBlock": BlockNumber(block_with_txn_with_log['number'] - 1),
         }
-        result = web3.eth.getLogs(filter_params)
+        result = web3.eth.get_logs(filter_params)
         assert len(result) == 0
 
         # Test with `address`
@@ -1267,7 +1544,7 @@ class EthModuleTest:
             "fromBlock": BlockNumber(0),
             "address": UNKNOWN_ADDRESS,
         }
-        result = web3.eth.getLogs(filter_params)
+        result = web3.eth.get_logs(filter_params)
         assert len(result) == 0
 
         # Test with multiple `address`
@@ -1277,10 +1554,10 @@ class EthModuleTest:
             "fromBlock": BlockNumber(0),
             "address": [UNKNOWN_ADDRESS, UNKNOWN_ADDRESS],
         }
-        result = web3.eth.getLogs(filter_params)
+        result = web3.eth.get_logs(filter_params)
         assert len(result) == 0
 
-    def test_eth_getLogs_with_logs(
+    def test_eth_get_logs_with_logs(
         self,
         web3: "Web3",
         block_with_txn_with_log: BlockData,
@@ -1304,14 +1581,14 @@ class EthModuleTest:
             "fromBlock": block_with_txn_with_log['number'],
             "toBlock": block_with_txn_with_log['number'],
         }
-        result = web3.eth.getLogs(filter_params)
+        result = web3.eth.get_logs(filter_params)
         assert_contains_log(result)
 
         # specify only `from_block`. by default `to_block` should be 'latest'
         filter_params = {
             "fromBlock": BlockNumber(0),
         }
-        result = web3.eth.getLogs(filter_params)
+        result = web3.eth.get_logs(filter_params)
         assert_contains_log(result)
 
         # Test with `address`
@@ -1322,7 +1599,7 @@ class EthModuleTest:
             "address": emitter_contract_address,
         }
 
-    def test_eth_getLogs_with_logs_topic_args(
+    def test_eth_get_logs_with_logs_topic_args(
         self,
         web3: "Web3",
         block_with_txn_with_log: BlockData,
@@ -1348,7 +1625,7 @@ class EthModuleTest:
                 HexStr('0x000000000000000000000000000000000000000000000000000000000000d431')],
         }
 
-        result = web3.eth.getLogs(filter_params)
+        result = web3.eth.get_logs(filter_params)
         assert_contains_log(result)
 
         # Test with None indexed arg
@@ -1358,17 +1635,17 @@ class EthModuleTest:
                 HexStr('0x057bc32826fbe161da1c110afcdcae7c109a8b69149f727fc37a603c60ef94ca'),
                 None],
         }
-        result = web3.eth.getLogs(filter_params)
+        result = web3.eth.get_logs(filter_params)
         assert_contains_log(result)
 
-    def test_eth_getLogs_with_logs_none_topic_args(self, web3: "Web3") -> None:
+    def test_eth_get_logs_with_logs_none_topic_args(self, web3: "Web3") -> None:
         # Test with None overflowing
         filter_params: FilterParams = {
             "fromBlock": BlockNumber(0),
             "topics": [None, None, None],
         }
 
-        result = web3.eth.getLogs(filter_params)
+        result = web3.eth.get_logs(filter_params)
         assert len(result) == 0
 
     def test_eth_call_old_contract_state(
@@ -1400,14 +1677,28 @@ class EthModuleTest:
         if pending_call_result != 1:
             raise AssertionError("pending call result was %d instead of 1" % pending_call_result)
 
-    def test_eth_uninstallFilter(self, web3: "Web3") -> None:
+    def test_eth_uninstallFilter_deprecated(self, web3: "Web3") -> None:
         filter = web3.eth.filter({})
         assert is_string(filter.filter_id)
 
-        success = web3.eth.uninstallFilter(filter.filter_id)
+        with pytest.warns(DeprecationWarning,
+                          match="uninstallFilter is deprecated in favor of uninstall_filter"):
+            success = web3.eth.uninstallFilter(filter.filter_id)
         assert success is True
 
-        failure = web3.eth.uninstallFilter(filter.filter_id)
+        with pytest.warns(DeprecationWarning,
+                          match="uninstallFilter is deprecated in favor of uninstall_filter"):
+            failure = web3.eth.uninstallFilter(filter.filter_id)
+        assert failure is False
+
+    def test_eth_uninstall_filter(self, web3: "Web3") -> None:
+        filter = web3.eth.filter({})
+        assert is_string(filter.filter_id)
+
+        success = web3.eth.uninstall_filter(filter.filter_id)
+        assert success is True
+
+        failure = web3.eth.uninstall_filter(filter.filter_id)
         assert failure is False
 
     def test_eth_getTransactionFromBlock_deprecation(
@@ -1420,15 +1711,32 @@ class EthModuleTest:
         with pytest.raises(DeprecationWarning):
             web3.eth.getCompilers()
 
-    def test_eth_submitHashrate(self, web3: "Web3") -> None:
+    def test_eth_submit_hashrate(self, web3: "Web3") -> None:
         # node_id from EIP 1474: https://github.com/ethereum/EIPs/pull/1474/files
         node_id = HexStr('59daa26581d0acd1fce254fb7e85952f4c09d0915afd33d3886cd914bc7d283c')
-        result = web3.eth.submitHashrate(5000, node_id)
+        result = web3.eth.submit_hashrate(5000, node_id)
         assert result is True
 
-    def test_eth_submitWork(self, web3: "Web3") -> None:
+    def test_eth_submitHashrate_deprecated(self, web3: "Web3") -> None:
+        # node_id from EIP 1474: https://github.com/ethereum/EIPs/pull/1474/files
+        node_id = HexStr('59daa26581d0acd1fce254fb7e85952f4c09d0915afd33d3886cd914bc7d283c')
+        with pytest.warns(DeprecationWarning,
+                          match='submitHashrate is deprecated in favor of submit_hashrate'):
+            result = web3.eth.submitHashrate(5000, node_id)
+        assert result is True
+
+    def test_eth_submit_work(self, web3: "Web3") -> None:
         nonce = 1
         pow_hash = HexStr('0x1234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef')
         mix_digest = HexStr('0xD1FE5700000000000000000000000000D1FE5700000000000000000000000000')
-        result = web3.eth.submitWork(nonce, pow_hash, mix_digest)
+        result = web3.eth.submit_work(nonce, pow_hash, mix_digest)
+        assert result is False
+
+    def test_eth_submitWork_deprecated(self, web3: "Web3") -> None:
+        nonce = 1
+        pow_hash = HexStr('0x1234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef')
+        mix_digest = HexStr('0xD1FE5700000000000000000000000000D1FE5700000000000000000000000000')
+        with pytest.warns(DeprecationWarning,
+                          match="submitWork is deprecated in favor of submit_work"):
+            result = web3.eth.submitWork(nonce, pow_hash, mix_digest)
         assert result is False
